@@ -1,3 +1,10 @@
+# !/usr/bin/env python
+# -*- coding: utf-8 -*-
+# @Time    : 2023/01/24
+# @Author  : longchengguxiao
+# @File    : nonebot_plugin_pvz
+# @Version : 3.8.9 Python
+
 from PIL import Image, ImageDraw, ImageFont
 from typing import List, Tuple
 import numpy as np
@@ -1526,6 +1533,9 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
         if args and args[0] in ["易", "中", "难", "地狱"]:
             state["mode"] = args[0]
         state["lawn"] = (users[users_id.index(user_id)][1]).split(",")
+        if len(set(state["lawn"])) == 1 and set(state["lawn"]).pop() == "0":
+            await asyncio.sleep(1)
+            await play_with_computer_zombie.finish("草坪没有植物，是想要脑子被吃掉嘛喂！可以通过'放置'来向草坪上置放植物哦~")
     else:
         await asyncio.sleep(1)
         await play_with_computer_zombie.finish("您暂未开启草坪,请通过'查看草坪'来开启", at_sender=True)
